Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCNINetworkInterface ¶
func NewCNINetworkInterface(conf InitConfig) (types.ContainerNetwork, error)
NewCNINetworkInterface creates the ContainerNetwork interface for the CNI backend. Note: The networks are not loaded from disk until a method is called.
Types ¶
type InitConfig ¶
type InitConfig struct {
// CNIConfigDir is directory where the cni config files are stored.
CNIConfigDir string
// CNIPluginDirs is a list of directories where cni should look for the plugins.
CNIPluginDirs []string
// DefaultNetwork is the name for the default network.
DefaultNetwork string
// DefaultSubnet is the default subnet for the default network.
DefaultSubnet string
// IsMachine describes whenever podman runs in a podman machine environment.
IsMachine bool
// LockFile is the path to lock file.
LockFile string
}
Click to show internal directories.
Click to hide internal directories.